////////////////////////////////////////////////////////////////////////////////////////////////
//                                                                                            //
//                                       WATTO STUDIOS                                        //
//                             Java Code, Programs, and Software                              //
//                                    http://www.watto.org                                    //
//                                                                                            //
//                           Copyright (C) 2004-2010  WATTO Studios                           //
//                                                                                            //
// This program is free software; you can redistribute it and/or modify it under the terms of //
// the GNU General Public License published by the Free Software Foundation; either version 2 //
// of the License, or (at your option) any later versions. This program is distributed in the //
// hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranties //
// of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License //
// at http://www.gnu.org for more details. For updates and information about this program, go //
// to the WATTO Studios website at http://www.watto.org or email watto@watto.org . Thanks! :) //
//                                                                                            //
////////////////////////////////////////////////////////////////////////////////////////////////

package org.watto.program.android.weightpoints;

import org.watto.android.Settings;
import org.watto.android.WSAboutScreen;
import org.watto.android.component.ButtonGroup;
import org.watto.android.component.WSAndroidPopup;
import org.watto.android.component.WSRadioButtonDropdown;
import org.watto.android.event.WSViewClickableInterface;
import org.watto.android.event.listener.WSViewClickableListener;
import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.text.InputType;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.RadioButton;
import android.widget.TableRow;


/***********************************************************************************************
Calculates the Weight Points value for a food product
***********************************************************************************************/
public class WeightPointsCalculator extends Activity implements WSViewClickableInterface {

  /***********************************************************************************************
  Calculates the points value for the Australian screen inputs
  @return the points value
  ***********************************************************************************************/
  public double calculateAlcoholPointsPlus(){

    double proteinValue = getProtein();
    if (proteinValue < 0) {
      return -1;
    }

    double carbohydratesValue = getCarbohydrates();
    if (carbohydratesValue < 0) {
      return -1;
    }

    double fatValue = getFat();
    if (fatValue < 0) {
      return -1;
    }

    double fiberValue = getFiber();
    if (fiberValue < 0) {
      return -1;
    }

    double alcoholValue = getAlcohol();
    if (alcoholValue < 0) {
      return -1;
    }

    double sugarAlcoholValue = getSugarAlcohol();
    if (sugarAlcoholValue < 0) {
      return -1;
    }

    boolean halfPoints = Settings.getBoolean("HalfPoints");
    return WeightPointsHelper.calculateAlcoholPointsPlus(proteinValue,carbohydratesValue,fatValue,fiberValue,alcoholValue,sugarAlcoholValue,halfPoints);
  }


  /***********************************************************************************************
  Calculates the points value for the Australian screen inputs
  @return the points value
  ***********************************************************************************************/
  public double calculateAustraliaPoints(){

    double kilojoulesValue = getKilojoules();
    if (kilojoulesValue < 0) {
      return -1;
    }

    double saturatedFatValue = getSaturatedFat();
    if (saturatedFatValue < 0) {
      return -1;
    }

    boolean halfPoints = Settings.getBoolean("HalfPoints");
    return WeightPointsHelper.calculateAustraliaPoints(kilojoulesValue,saturatedFatValue,halfPoints);
  }


  /***********************************************************************************************
  Calculates the points value for the screen input, and displays the result in the results field
  ***********************************************************************************************/
  public void calculatePoints(){

    // Clear the results field
    EditText resultsField = (EditText)findViewById(R.id.tf_result);
    resultsField.setText("");

    double result = 0;

    String pointsType = Settings.getString("pointsType");

    if (pointsType.equals("points")) {
      // Calssic points
      String pointsCountry = Settings.getString("pointsCountry");

      if (pointsCountry.equals("australia")) {
        result = calculateAustraliaPoints();
      }
      else if (pointsCountry.equals("uk")) {
        result = calculateUKPoints();
      }
      else if (pointsCountry.equals("usa")) {
        result = calculateUSAPoints();
      }
    }
    else if (pointsType.equals("pro_points")) {
      // Pro Points
      result = calculateProPoints();
    }
    else if (pointsType.equals("points_plus")) {
      // Points Plus
      if (((RadioButton)findViewById(R.id.radio_points_plus_food)).isChecked()) {
        result = calculatePointsPlus();
      }
      else if (((RadioButton)findViewById(R.id.radio_points_plus_alcohol)).isChecked()) {
        result = calculateAlcoholPointsPlus();
      }
    }

    // there was an error in the calculation
    if (result < 0) {
      return;
    }

    boolean decimalPoints = Settings.getBoolean("DecimalPoints");
    if (decimalPoints) {
      resultsField.setText("" + result);
    }
    else if (!decimalPoints) {
      resultsField.setText("" + (int)result);
    }
  }


  /***********************************************************************************************
  Calculates the points value for the Australian screen inputs
  @return the points value
  ***********************************************************************************************/
  public double calculatePointsPlus(){

    double proteinValue = getProtein();
    if (proteinValue < 0) {
      return -1;
    }

    double carbohydratesValue = getCarbohydrates();
    if (carbohydratesValue < 0) {
      return -1;
    }

    double fatValue = getFat();
    if (fatValue < 0) {
      return -1;
    }

    double fiberValue = getFiber();
    if (fiberValue < 0) {
      return -1;
    }

    boolean halfPoints = Settings.getBoolean("HalfPoints");
    return WeightPointsHelper.calculatePointsPlus(proteinValue,carbohydratesValue,fatValue,fiberValue,halfPoints);
  }


  /***********************************************************************************************
  Calculates the points value for the Australian screen inputs
  @return the points value
  ***********************************************************************************************/
  public double calculateProPoints(){

    double proteinValue = getProtein();
    if (proteinValue < 0) {
      return -1;
    }

    double carbohydratesValue = getCarbohydrates();
    if (carbohydratesValue < 0) {
      return -1;
    }

    double fatValue = getFat();
    if (fatValue < 0) {
      return -1;
    }

    double fiberValue = getFiber();
    if (fiberValue < 0) {
      return -1;
    }

    boolean halfPoints = Settings.getBoolean("HalfPoints");
    return WeightPointsHelper.calculateProPoints(proteinValue,carbohydratesValue,fatValue,fiberValue,halfPoints);
  }


  /***********************************************************************************************
  Calculates the points value for the UK screen inputs
  @return the points value
  ***********************************************************************************************/
  public double calculateUKPoints(){

    double caloriesValue = getCalories();
    if (caloriesValue < 0) {
      return -1;
    }

    double saturatedFatValue = getSaturatedFat();
    if (saturatedFatValue < 0) {
      return -1;
    }

    boolean halfPoints = Settings.getBoolean("HalfPoints");
    return WeightPointsHelper.calculateUKPoints(caloriesValue,saturatedFatValue,halfPoints);
  }


  /***********************************************************************************************
  Calculates the points value for the USA screen inputs
  @return the points value
  ***********************************************************************************************/
  public double calculateUSAPoints(){

    double caloriesValue = getCalories();
    if (caloriesValue < 0) {
      return -1;
    }

    double fatValue = getFat();
    if (fatValue < 0) {
      return -1;
    }

    double fiberValue = getFiber();
    if (fiberValue < 0) {
      return -1;
    }

    boolean halfPoints = Settings.getBoolean("HalfPoints");
    return WeightPointsHelper.calculateUSAPoints(caloriesValue,fatValue,fiberValue,halfPoints);
  }


  /***********************************************************************************************
  Calculates the alcohol value from the screen input, as a <i>double</i>. Also performs error
  checking on the value, and prompts the user if it is invalid.
  @return the alcohol value
  ***********************************************************************************************/
  public double getAlcohol(){
    return getFieldValue(R.id.tf_alcohol,R.string.error_alcohol_missing,R.string.error_alcohol_not_numerical);
  }


  /***********************************************************************************************
  Calculates the calories value from the screen input, as a <i>double</i>. Also performs error
  checking on the value, and prompts the user if it is invalid.
  @return the calories value
  ***********************************************************************************************/
  public double getCalories(){
    return getFieldValue(R.id.tf_calories,R.string.error_calories_missing,R.string.error_calories_not_numerical);
  }


  /***********************************************************************************************
  Calculates the carbohydrates value from the screen input, as a <i>double</i>. Also performs error
  checking on the value, and prompts the user if it is invalid.
  @return the carbohydrates value
  ***********************************************************************************************/
  public double getCarbohydrates(){
    return getFieldValue(R.id.tf_carbohydrates,R.string.error_carbohydrates_missing,R.string.error_carbohydrates_not_numerical);
  }


  /***********************************************************************************************
  Calculates the fat value from the screen input, as a <i>double</i>. Also performs error
  checking on the value, and prompts the user if it is invalid.
  @return the fat value
  ***********************************************************************************************/
  public double getFat(){
    return getFieldValue(R.id.tf_fat,R.string.error_fat_missing,R.string.error_fat_not_numerical);
  }


  /***********************************************************************************************
  Calculates the fiber value from the screen input, as a <i>double</i>. Also performs error
  checking on the value, and prompts the user if it is invalid.
  @return the fiber value
  ***********************************************************************************************/
  public double getFiber(){
    return getFieldValue(R.id.tf_fiber,R.string.error_fiber_missing,R.string.error_fiber_not_numerical);
  }


  /***********************************************************************************************
  Gets the <i>double</i> value for a screen input. Also performs error checking on the value, and
  prompts the user if it is invalid.
  @param fieldID the resource ID of the field to get the value from
  @param missingError the String ID of the "value missing" error message
  @param numberError the String ID of the "value is not a number" error message 
  @return the field value, and a <i>double</i>
  ***********************************************************************************************/
  public double getFieldValue(int fieldID,int missingError,int numberError){
    EditText field = (EditText)findViewById(fieldID);
    String stringValue = field.getText().toString();

    if (stringValue.equals("")) {
      //WSAndroidPopup.showError(this,missingError);
      //return -1;

      // Return '0' as the result for this field
      return 0;
    }

    double doubleValue = 0;
    try {
      doubleValue = Double.parseDouble(stringValue);
    }
    catch (NumberFormatException e) {
      WSAndroidPopup.showError(this,numberError);
      return -1;
    }

    return doubleValue;
  }


  /***********************************************************************************************
  Calculates the kilojoules value from the screen input, as a <i>double</i>. Also performs error
  checking on the value, and prompts the user if it is invalid.
  @return the kilojoules value
  ***********************************************************************************************/
  public double getKilojoules(){
    return getFieldValue(R.id.tf_kilojoules,R.string.error_kilojoules_missing,R.string.error_kilojoules_not_numerical);
  }


  /***********************************************************************************************
  Calculates the protein value from the screen input, as a <i>double</i>. Also performs error
  checking on the value, and prompts the user if it is invalid.
  @return the protein value
  ***********************************************************************************************/
  public double getProtein(){
    return getFieldValue(R.id.tf_protein,R.string.error_protein_missing,R.string.error_protein_not_numerical);
  }


  /***********************************************************************************************
  Calculates the saturated fat value from the screen input, as a <i>double</i>. Also performs error
  checking on the value, and prompts the user if it is invalid.
  @return the saturated fat value
  ***********************************************************************************************/
  public double getSaturatedFat(){
    return getFieldValue(R.id.tf_saturated_fat,R.string.error_saturated_fat_missing,R.string.error_saturated_fat_not_numerical);
  }


  /***********************************************************************************************
  Calculates the sugar alcohol value from the screen input, as a <i>double</i>. Also performs error
  checking on the value, and prompts the user if it is invalid.
  @return the sugar alcohol value
  ***********************************************************************************************/
  public double getSugarAlcohol(){
    return getFieldValue(R.id.tf_sugar_alcohol,R.string.error_sugar_alcohol_missing,R.string.error_sugar_alcohol_not_numerical);
  }


  /***********************************************************************************************
  Hides the screen fields that are not used for the chosen formula
  ***********************************************************************************************/
  public void hideScreenFields(){
    String pointsType = Settings.getString("pointsType");

    TableRow pointsClassicCountry = (TableRow)findViewById(R.id.row_points_classic_country);
    TableRow pointsPlusAlcohol = (TableRow)findViewById(R.id.row_points_plus_alcohol);

    TableRow proteinRow = (TableRow)findViewById(R.id.row_protein);
    TableRow carbohydratesRow = (TableRow)findViewById(R.id.row_carbohydrates);
    TableRow caloriesRow = (TableRow)findViewById(R.id.row_calories);
    TableRow fatRow = (TableRow)findViewById(R.id.row_fat);
    TableRow fiberRow = (TableRow)findViewById(R.id.row_fiber);
    TableRow kilojoulesRow = (TableRow)findViewById(R.id.row_kilojoules);
    TableRow saturatedFatRow = (TableRow)findViewById(R.id.row_saturated_fat);
    TableRow alcoholRow = (TableRow)findViewById(R.id.row_alcohol);
    TableRow sugarAlcoholRow = (TableRow)findViewById(R.id.row_sugar_alcohol);

    if (pointsType.equals("points")) {
      // classic points
      String pointsCountry = Settings.getString("pointsCountry");

      pointsClassicCountry.setVisibility(View.VISIBLE);
      pointsPlusAlcohol.setVisibility(View.GONE);

      proteinRow.setVisibility(View.GONE);
      carbohydratesRow.setVisibility(View.GONE);
      alcoholRow.setVisibility(View.GONE);
      sugarAlcoholRow.setVisibility(View.GONE);

      if (pointsCountry.equals("australia")) {
        caloriesRow.setVisibility(View.GONE);
        fatRow.setVisibility(View.GONE);
        fiberRow.setVisibility(View.GONE);
        kilojoulesRow.setVisibility(View.VISIBLE);
        saturatedFatRow.setVisibility(View.VISIBLE);
      }
      else if (pointsCountry.equals("uk")) {
        caloriesRow.setVisibility(View.VISIBLE);
        fatRow.setVisibility(View.GONE);
        fiberRow.setVisibility(View.GONE);
        kilojoulesRow.setVisibility(View.GONE);
        saturatedFatRow.setVisibility(View.VISIBLE);
      }
      else if (pointsCountry.equals("usa")) {
        caloriesRow.setVisibility(View.VISIBLE);
        fatRow.setVisibility(View.VISIBLE);
        fiberRow.setVisibility(View.VISIBLE);
        kilojoulesRow.setVisibility(View.GONE);
        saturatedFatRow.setVisibility(View.GONE);
      }

    }
    else if (pointsType.equals("pro_points")) {
      // pro points
      pointsClassicCountry.setVisibility(View.GONE);
      pointsPlusAlcohol.setVisibility(View.GONE);

      proteinRow.setVisibility(View.VISIBLE);
      carbohydratesRow.setVisibility(View.VISIBLE);
      caloriesRow.setVisibility(View.GONE);
      fatRow.setVisibility(View.VISIBLE);
      fiberRow.setVisibility(View.VISIBLE);
      kilojoulesRow.setVisibility(View.GONE);
      saturatedFatRow.setVisibility(View.GONE);
      alcoholRow.setVisibility(View.GONE);
      sugarAlcoholRow.setVisibility(View.GONE);
    }
    else if (pointsType.equals("points_plus")) {
      // pro points
      pointsClassicCountry.setVisibility(View.GONE);
      pointsPlusAlcohol.setVisibility(View.VISIBLE);

      proteinRow.setVisibility(View.VISIBLE);
      carbohydratesRow.setVisibility(View.VISIBLE);
      caloriesRow.setVisibility(View.GONE);
      fatRow.setVisibility(View.VISIBLE);
      fiberRow.setVisibility(View.VISIBLE);
      kilojoulesRow.setVisibility(View.GONE);
      saturatedFatRow.setVisibility(View.GONE);

      boolean showingAlcohol = Settings.getBoolean("pointsPlusAlcohol");

      if (showingAlcohol) {
        ((RadioButton)findViewById(R.id.radio_points_plus_alcohol)).setChecked(true);
        alcoholRow.setVisibility(View.VISIBLE);
        sugarAlcoholRow.setVisibility(View.VISIBLE);
      }
      else {
        // showing food
        ((RadioButton)findViewById(R.id.radio_points_plus_food)).setChecked(true);
        alcoholRow.setVisibility(View.GONE);
        sugarAlcoholRow.setVisibility(View.GONE);
      }

    }

  }


  /***********************************************************************************************
  Performs an action when a single-click event is triggered on a <code>View</code>
  @param source the <code>View</code> that triggered the event
  @return <b>true</b> if the event was handled by this class<br />
          <b>false</b> if the event wasn't handled by this class, and thus should be passed on to
          the parent class for handling.
  ***********************************************************************************************/
  public boolean onClick(View source){
    int id = source.getId();
    if (id == R.id.button_calculate) {
      calculatePoints();

      // scroll to the bottom of the screen so that the result field is shown
      // NO LONGER NEEDED BECAUSE THE RESULTS FIELD IS FIXED ON THE BOTTOM OF THE SCREEN
      //ScrollView scrollView = (ScrollView)findViewById(R.id.main_scroll_view);
      //scrollView.scrollTo(0,10000);
    }
    else if (id == R.id.button_clear) {
      clearFieldValues();
    }
    else if (id == R.id.dropdown_points_type) {
      //Settings.set("pointsType",((WSRadioButtonDropdown)source).getSelectedValue());
      hideScreenFields();
    }
    else if (id == R.id.dropdown_points_classic_country) {
      //Settings.set("pointsCountry",((WSRadioButtonDropdown)source).getSelectedValue());
      hideScreenFields();
    }
    else if (id == R.id.radio_points_plus_food) {
      Settings.set("pointsPlusAlcohol",false);
      hideScreenFields();
    }
    else if (id == R.id.radio_points_plus_alcohol) {
      Settings.set("pointsPlusAlcohol",true);
      hideScreenFields();
    }
    else {
      return false;
    }
    return true;
  }


  /***********************************************************************************************
  Creates the <code>Activity</code> from the XML file
  @param savedInstanceState the saved state of the <code>Activity</code>
  ***********************************************************************************************/
  public void onCreate(Bundle savedInstanceState){
    super.onCreate(savedInstanceState);

    // Load and prepare the settings, if the application has only just been loaded
    if (!Settings.hasApplication()) {
      Settings.setApplication(this);
      setDefaultSettings();
    }

    // Creates the view from the XML file
    setContentView(R.layout.weight_points_calculator);

    // Set the View Click Listeners
    WSViewClickableListener viewClickableListener = new WSViewClickableListener(this);
    ((Button)findViewById(R.id.button_calculate)).setOnClickListener(viewClickableListener);
    ((Button)findViewById(R.id.button_clear)).setOnClickListener(viewClickableListener);

    // Sets the click listener for the RadioButtons, and assigns them to a button group
    RadioButton pointsPlusFoodRadio = (RadioButton)findViewById(R.id.radio_points_plus_food);
    pointsPlusFoodRadio.setOnClickListener(viewClickableListener);
    RadioButton pointsPlusAlcoholRadio = (RadioButton)findViewById(R.id.radio_points_plus_alcohol);
    pointsPlusAlcoholRadio.setOnClickListener(viewClickableListener);

    // Assign the pointsPlus RadioButtons to a group
    new ButtonGroup(pointsPlusFoodRadio,pointsPlusAlcoholRadio);

    // Sets the default value and the click listeners for the RadioButtonDropdowns
    WSRadioButtonDropdown countryDropdown = (WSRadioButtonDropdown)findViewById(R.id.dropdown_points_classic_country);
    //countryDropdown.setSelectedValue(Settings.getString("pointsCountry"));
    countryDropdown.setItemChangedListener(viewClickableListener);

    WSRadioButtonDropdown pointsTypeDropdown = (WSRadioButtonDropdown)findViewById(R.id.dropdown_points_type);
    //pointsTypeDropdown.setSelectedValue(Settings.getString("pointsType"));
    pointsTypeDropdown.setItemChangedListener(viewClickableListener);

  }


  /***********************************************************************************************
  Creates the <code>Menu</code> from the XML file when the Options button is pressed
  @param menu the <code>Menu</code> <code>View</code> to populate with menu items
  @return <b>true</b> to display the menu, <br />
          <b>false</b> to keep the menu hidden.
  ***********************************************************************************************/
  public boolean onCreateOptionsMenu(Menu menu){
    MenuInflater inflater = getMenuInflater();
    inflater.inflate(R.menu.weight_points_calculator,menu);
    return true;
  }


  /***********************************************************************************************
  Performs an action when a <code>MenuItem</code> is selected in the Options menu
  @param item the <code>MenuItem</code> that was selected
  @return <b>true</b> if the event was handled by this class<br />
          <b>false</b> if the event wasn't handled by this class, and thus should be passed on to
          the parent class for handling.
  ***********************************************************************************************/
  public boolean onOptionsItemSelected(MenuItem item){
    int id = item.getItemId();

    if (id == R.id.menu_settings) {
      showSettings();
      return true;
    }
    else if (id == R.id.menu_about) {
      showAbout();
      return true;
    }
    return false;
  }


  /***********************************************************************************************
  Hides the screen fields whenever the <code>Activity</code> is brought to the foreground
  ***********************************************************************************************/
  public void onResume(){
    super.onResume();
    

    // Hide the screen fields according to the chosen formula
    hideScreenFields();

    // Sets the input fields as decimal or not, according to the settings
    setDecimalFields();

  }
  
  
  /***********************************************************************************************
  Clears the values of all the fields
  ***********************************************************************************************/
  public void clearFieldValues(){
    ((EditText)findViewById(R.id.tf_protein)).setText("");
    ((EditText)findViewById(R.id.tf_carbohydrates)).setText("");
    ((EditText)findViewById(R.id.tf_calories)).setText("");
    ((EditText)findViewById(R.id.tf_fat)).setText("");
    ((EditText)findViewById(R.id.tf_fiber)).setText("");
    ((EditText)findViewById(R.id.tf_kilojoules)).setText("");
    ((EditText)findViewById(R.id.tf_saturated_fat)).setText("");
    ((EditText)findViewById(R.id.tf_alcohol)).setText("");
    ((EditText)findViewById(R.id.tf_sugar_alcohol)).setText("");
    ((EditText)findViewById(R.id.tf_result)).setText("");
  }


  /***********************************************************************************************
  Sets the input type on the fields based on whether the user wants to use decimals or not. Also
  clears the fields.
  ***********************************************************************************************/
  public void setDecimalFields(){
    //SharedPreferences settings = PreferenceManager.getDefaultSharedPreferences(this);
    //boolean decimalPoints = settings.getBoolean("DecimalPoints",true);
    boolean decimalPoints = true;

    EditText proteinField = (EditText)findViewById(R.id.tf_protein);
    EditText carbohydratesField = (EditText)findViewById(R.id.tf_carbohydrates);
    EditText caloriesField = (EditText)findViewById(R.id.tf_calories);
    EditText fatField = (EditText)findViewById(R.id.tf_fat);
    EditText fiberField = (EditText)findViewById(R.id.tf_fiber);
    EditText kilojoulesField = (EditText)findViewById(R.id.tf_kilojoules);
    EditText saturatedFatField = (EditText)findViewById(R.id.tf_saturated_fat);
    EditText alcoholField = (EditText)findViewById(R.id.tf_alcohol);
    EditText sugarAlcoholField = (EditText)findViewById(R.id.tf_sugar_alcohol);

    int inputType = 0;
    if (decimalPoints) {
      inputType = InputType.TYPE_CLASS_NUMBER | InputType.TYPE_NUMBER_FLAG_DECIMAL;
    }
    else if (!decimalPoints) {
      inputType = InputType.TYPE_CLASS_NUMBER;
    }

    proteinField.setInputType(inputType);
    proteinField.setText("");

    carbohydratesField.setInputType(inputType);
    carbohydratesField.setText("");

    caloriesField.setInputType(inputType);
    caloriesField.setText("");

    fatField.setInputType(inputType);
    fatField.setText("");

    fiberField.setInputType(inputType);
    fiberField.setText("");

    kilojoulesField.setInputType(inputType);
    kilojoulesField.setText("");

    saturatedFatField.setInputType(inputType);
    saturatedFatField.setText("");

    alcoholField.setInputType(inputType);
    alcoholField.setText("");

    sugarAlcoholField.setInputType(inputType);
    sugarAlcoholField.setText("");

    EditText resultsField = (EditText)findViewById(R.id.tf_result);
    resultsField.setText("");

  }


  /***********************************************************************************************
  Sets the default values for some of the settings
  ***********************************************************************************************/
  public void setDefaultSettings(){
    
    if (Settings.get("pointsType").equals("")){
      Settings.set("pointsType","points_plus");
    }
    if (Settings.get("pointsCountry").equals("")){
      Settings.set("pointsCountry","usa");
    }
    
    boolean alcoholChosen = Settings.getBoolean("pointsPlusAlcohol"); // will return 'false' if not set
    // Set it to 'false' if unset, otherwise set it to the set value (which is true or false)
    Settings.set("pointsPlusAlcohol",alcoholChosen); // showing alcohol or food for the points_plus scheme?
    
  }


  /***********************************************************************************************
  Shows the about <code>Activity</code>
  ***********************************************************************************************/
  public void showAbout(){
    Intent aboutActivity = new Intent(getBaseContext(),WSAboutScreen.class);
    startActivity(aboutActivity);
  }


  /***********************************************************************************************
  Shows the settings <code>Activity</code>
  ***********************************************************************************************/
  public void showSettings(){
    Intent settingsActivity = new Intent(getBaseContext(),WeightPointsSettings.class);
    startActivity(settingsActivity);
  }

}